@@ -122,7 +122,7 @@ wflow_open <- function(files,
       "To continue using your site as is, you can:\n\n",
       "1. Create a new R Markdown file by copying an existing one\n\n",
       "2. Install the beta release of workflowr and use its wflow_open:\n\n",
-      "devtools::install_github(\"jdblischak/workflowrBeta\")\n\n",
+      "remotes::install_github(\"jdblischak/workflowrBeta\")\n\n",
       "To update to a workflowr 1.0+ site, you can:\n\n",
       "1. Run wflow_update() to preview the files that would be affected\n\n",
       "2. Follow the instructions in ?wflow_update to make the transition\n\n",
