@@ -1,6 +1,6 @@
 #' Create table of contents
 #'
-#' \code{wfow_toc} creates a table of contents of the published R Markdown
+#' \code{wflow_toc} creates a table of contents of the published R Markdown
 #' files. The output is in markdown format, so you can paste it into a document
 #' such as \code{index.Rmd}. If the R package
 #' \href{https://cran.r-project.org/package=clipr}{clipr} is installed, the
@@ -17,9 +17,9 @@
 #' \code{install.packages("clipr")}
 #'
 #' \item Check that the system keyboard is writable. Run
-#' \code{\link[clipr]{clipr_available}} and \code{\link[clipr]{dr_clipr}}.
+#' \code{\link[clipr]{clipr_available}} and \code{\link[clipr:clipr_available]{dr_clipr}}.
 #'
-#' \item If it's still not working, set \code{keyboard = FALSE} to send the
+#' \item If it's still not working, set \code{clipboard = FALSE} to send the
 #' table of contents to the R console to manually copy-paste.
 #'
 #' }
@@ -30,17 +30,20 @@
 #'   clipboard. Only relevant if
 #'   \href{https://cran.r-project.org/package=clipr}{clipr} package is installed
 #'   and the system keyboard is available.
+#' @param only_published logical (default: TRUE) Include only published contents.
 #' @inheritParams wflow_git_commit
 #'
 #' @return Invisibly returns the table of contents as a character vector.
 #'
 #' @export
-wflow_toc <- function(ignore_nav_bar = TRUE, clipboard = TRUE, project = ".") {
+wflow_toc <- function(ignore_nav_bar = TRUE, clipboard = TRUE,
+                      only_published = TRUE, project = ".") {
 
   # Check input arguments ------------------------------------------------------
 
   assert_is_flag(ignore_nav_bar)
   assert_is_flag(clipboard)
+  assert_is_flag(only_published)
   check_wd_exists()
   assert_is_single_directory(project)
   project <- absolute(project)
@@ -48,7 +51,12 @@ wflow_toc <- function(ignore_nav_bar = TRUE, clipboard = TRUE, project = ".") {
   # Create table of contents ---------------------------------------------------
 
   s <- wflow_status(project = project)
-  rmd <- rownames(s$status)[s$status$published]
+  if (only_published) {
+    rmd <- rownames(s$status)[s$status$published]
+  } else {
+    rmd <- rownames(s$status)
+  }
+
   html <- to_html(basename(rmd))
 
   # Obtains the toc except the documents in the navigation bar.
@@ -61,6 +69,16 @@ wflow_toc <- function(ignore_nav_bar = TRUE, clipboard = TRUE, project = ".") {
     rmd <- rmd[!html_in_nav]
   }
 
+  if (length(rmd) == 0) {
+    m <-
+      "No suitable content to be added to the TOC found. If you wish to
+      include unpublished contents, consider setting `only_published = FALSE`.
+      If you wish to include contents already linked in the navigation bar,
+      consider setting `ignore_nav_bar = FALSE`."
+    warning(wrap(m))
+    return(invisible(character()))
+  }
+
   titles <- vapply(rmd, get_rmd_title, character(1))
   titles <- ifelse(is.na(titles), basename(rmd), titles)
   toc <- glue::glue("1. [{titles}]({html})")
@@ -102,11 +120,14 @@ wflow_toc_addin <- function() {
 
   toc <- suppressMessages(wflow_toc(clipboard = FALSE))
 
-  if (length(toc) == 0)
-    stop(wrap(
-      "wflow_toc() addin: Couldn't find any published files", "(that aren't part
-      of the navigation bar). Use wflow_publish() first."),
-         call. = FALSE)
+  if (length(toc) == 0) {
+    m <-
+      "wflow_toc() addin: Couldn't find any published files (that aren't part
+      of the navigation bar). Use wflow_publish() first or call wflow_toc()
+      directly using one of the arguments described in the warning message
+      below."
+    stop(wrap(m), call. = FALSE)
+  }
 
   toc_single <- paste(toc, collapse = "\n")
   toc_single <- paste0(toc_single, "\n")
