@@ -101,9 +101,9 @@
 #' since it involves using your web browser to authenticate with your GitHub
 #' account. If it fails for any reason, it'd probably be easier to manually
 #' login to GitHub and create the repository yourself
-#' (\href{https://help.github.com/articles/creating-a-new-repository/}{instructions from GitHub}).
+#' (\href{https://docs.github.com/articles/creating-a-new-repository}{instructions from GitHub}).
 #' However, if you have time, please file an
-#' \href{https://github.com/jdblischak/workflowr/issues/new/choose}{Issue on
+#' \href{https://github.com/workflowr/workflowr/issues/new/choose}{Issue on
 #' GitHub} to report what happened, and importantly include which web browser
 #' you were using.
 #'
@@ -279,7 +279,7 @@ wflow_use_github <- function(username = NULL,
 
   host <- get_host_from_remote(path = project)
   if (navbar_link && !is.na(host)) {
-    site_yml$navbar$right <- list(list(icon = "fa-github",
+    site_yml$navbar$right <- list(list(icon = get_fa_brand_icon("github"),
                                        text = "Source code",
                                        href = host))
     yaml::write_yaml(site_yml, file = site_yml_fname)
@@ -377,7 +377,7 @@ create_gh_repo <- function(account, repository, account_is_organization = FALSE)
                          secret = "ac5e6d52e3bf71e4535149622f053b9f00f2e155")
 
   # Set user agent
-  ua <- httr::user_agent("https://github.com/jdblischak/workflowr")
+  ua <- httr::user_agent("https://github.com/workflowr/workflowr")
 
   message(glue::glue(
     "Requesting authorization for workflowr app to access GitHub account {account}"))
